# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compute_s3_sink.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63ompute_s3_sink.proto\x12\x0f\x63ompute_s3_sink\"\xb3\x02\n\x19S3SinkWorkerConfiguration\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0e\n\x06region\x18\x02 \x01(\t\x12*\n\x07objects\x18\x04 \x03(\x0b\x32\x19.compute_s3_sink.S3Object\x12/\n\ns3Provider\x18\x05 \x01(\x0e\x32\x1b.compute_s3_sink.S3Provider\x12I\n\x16userDefinedCredentials\x18\x06 \x01(\x0b\x32\'.compute_s3_sink.UserDefinedCredentialsH\x00\x12=\n\x10\x64qDspCredentials\x18\x07 \x01(\x0b\x32!.compute_s3_sink.DqDspCredentialsH\x00\x42\r\n\x0b\x63redentials\"8\n\x16UserDefinedCredentials\x12\x1e\n\x16userDefinedCredentials\x18\x01 \x01(\t\"H\n\x10\x44qDspCredentials\x12\x34\n\x07\x64spType\x18\x01 \x01(\x0e\x32#.compute_s3_sink.DspCredentialsType\"~\n\x08S3Object\x12\x12\n\ndependency\x18\x01 \x01(\t\x12)\n\x03zip\x18\x02 \x01(\x0b\x32\x1a.compute_s3_sink.ZipObjectH\x00\x12)\n\x03raw\x18\x03 \x01(\x0b\x32\x1a.compute_s3_sink.RawObjectH\x00\x42\x08\n\x06\x66ormat\"\x18\n\tRawObject\x12\x0b\n\x03key\x18\x01 \x01(\t\"{\n\tZipObject\x12\x31\n\nsingleFile\x18\x01 \x01(\x0b\x32\x1b.compute_s3_sink.SingleFileH\x00\x12\x33\n\x0b\x66ullContent\x18\x02 \x01(\x0b\x32\x1c.compute_s3_sink.FullContentH\x00\x42\x06\n\x04kind\"\'\n\nSingleFile\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\r\n\x0b\x46ullContent\"5\n\rS3Credentials\x12\x11\n\taccessKey\x18\x01 \x01(\t\x12\x11\n\tsecretKey\x18\x02 \x01(\t*\x1e\n\nS3Provider\x12\x07\n\x03\x41WS\x10\x00\x12\x07\n\x03GCS\x10\x01*!\n\x12\x44spCredentialsType\x12\x0b\n\x07SPLICKY\x10\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'compute_s3_sink_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_S3PROVIDER']._serialized_start=874
  _globals['_S3PROVIDER']._serialized_end=904
  _globals['_DSPCREDENTIALSTYPE']._serialized_start=906
  _globals['_DSPCREDENTIALSTYPE']._serialized_end=939
  _globals['_S3SINKWORKERCONFIGURATION']._serialized_start=43
  _globals['_S3SINKWORKERCONFIGURATION']._serialized_end=350
  _globals['_USERDEFINEDCREDENTIALS']._serialized_start=352
  _globals['_USERDEFINEDCREDENTIALS']._serialized_end=408
  _globals['_DQDSPCREDENTIALS']._serialized_start=410
  _globals['_DQDSPCREDENTIALS']._serialized_end=482
  _globals['_S3OBJECT']._serialized_start=484
  _globals['_S3OBJECT']._serialized_end=610
  _globals['_RAWOBJECT']._serialized_start=612
  _globals['_RAWOBJECT']._serialized_end=636
  _globals['_ZIPOBJECT']._serialized_start=638
  _globals['_ZIPOBJECT']._serialized_end=761
  _globals['_SINGLEFILE']._serialized_start=763
  _globals['_SINGLEFILE']._serialized_end=802
  _globals['_FULLCONTENT']._serialized_start=804
  _globals['_FULLCONTENT']._serialized_end=817
  _globals['_S3CREDENTIALS']._serialized_start=819
  _globals['_S3CREDENTIALS']._serialized_end=872
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: metering.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import attestation_pb2 as attestation__pb2
from . import data_room_pb2 as data__room__pb2
from . import integrity_store_pb2 as integrity__store__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0emetering.proto\x12\x08metering\x1a\x11\x61ttestation.proto\x1a\x0f\x64\x61ta_room.proto\x1a\x15integrity_store.proto\"[\n\x0b\x45nclaveInfo\x12\x1e\n\x16\x61ttestationSpecHashHex\x18\x01 \x01(\t\x12\x1a\n\rtaskQueueName\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x10\n\x0e_taskQueueName\"\xb3\x07\n\x0fMeteringRequest\x12/\n\tcreateDcr\x18\x01 \x01(\x0b\x32\x1a.metering.CreateDcrRequestH\x00\x12;\n\x0f\x63reateDcrCommit\x18\x02 \x01(\x0b\x32 .metering.CreateDcrCommitRequestH\x00\x12+\n\x07stopDcr\x18\x03 \x01(\x0b\x32\x18.metering.StopDcrRequestH\x00\x12\x39\n\x0epublishDataset\x18\x04 \x01(\x0b\x32\x1f.metering.PublishDatasetRequestH\x00\x12=\n\x10unpublishDataset\x18\x05 \x01(\x0b\x32!.metering.UnpublishDatasetRequestH\x00\x12\x39\n\x0eworkerMetadata\x18\x06 \x01(\x0b\x32\x1f.metering.WorkerMetadataRequestH\x00\x12O\n\x19submitWorkerExecutionTime\x18\x07 \x01(\x0b\x32*.metering.SubmitWorkerExecutionTimeRequestH\x00\x12\x39\n\x0e\x64\x63rInteraction\x18\x08 \x01(\x0b\x32\x1f.metering.DcrInteractionRequestH\x00\x12\x37\n\rcreateDataset\x18\t \x01(\x0b\x32\x1e.metering.CreateDatasetRequestH\x00\x12K\n\x17getOrCreateDatasetScope\x18\n \x01(\x0b\x32(.metering.GetOrCreateDatasetScopeRequestH\x00\x12\x39\n\x0emergeDcrCommit\x18\x0b \x01(\x0b\x32\x1f.metering.MergeDcrCommitRequestH\x00\x12S\n\x1bgetDataConnectorCredentials\x18\x0c \x01(\x0b\x32,.metering.GetDataConnectorCredentialsRequestH\x00\x12\x44\n\x0eintegrityStore\x18\r \x01(\x0b\x32*.integrity_store_api.IntegrityStoreRequestH\x00\x12]\n getAzureCommunicationCredentials\x18\x0e \x01(\x0b\x32\x31.metering.GetAzureCommunicationCredentialsRequestH\x00\x42\t\n\x07request\"\xc7\x07\n\x17MeteringSuccessResponse\x12\x30\n\tcreateDcr\x18\x01 \x01(\x0b\x32\x1b.metering.CreateDcrResponseH\x00\x12<\n\x0f\x63reateDcrCommit\x18\x02 \x01(\x0b\x32!.metering.CreateDcrCommitResponseH\x00\x12,\n\x07stopDcr\x18\x03 \x01(\x0b\x32\x19.metering.StopDcrResponseH\x00\x12:\n\x0epublishDataset\x18\x04 \x01(\x0b\x32 .metering.PublishDatasetResponseH\x00\x12>\n\x10unpublishDataset\x18\x05 \x01(\x0b\x32\".metering.UnpublishDatasetResponseH\x00\x12:\n\x0eworkerMetadata\x18\x06 \x01(\x0b\x32 .metering.WorkerMetadataResponseH\x00\x12P\n\x19submitWorkerExecutionTime\x18\x07 \x01(\x0b\x32+.metering.SubmitWorkerExecutionTimeResponseH\x00\x12:\n\x0e\x64\x63rInteraction\x18\x08 \x01(\x0b\x32 .metering.DcrInteractionResponseH\x00\x12\x38\n\rcreateDataset\x18\t \x01(\x0b\x32\x1f.metering.CreateDatasetResponseH\x00\x12L\n\x17getOrCreateDatasetScope\x18\n \x01(\x0b\x32).metering.GetOrCreateDatasetScopeResponseH\x00\x12:\n\x0emergeDcrCommit\x18\x0b \x01(\x0b\x32 .metering.MergeDcrCommitResponseH\x00\x12Q\n\x18\x64\x61taConnectorCredentials\x18\x0c \x01(\x0b\x32-.metering.GetDataConnectorCredentialsResponseH\x00\x12\x45\n\x0eintegrityStore\x18\r \x01(\x0b\x32+.integrity_store_api.IntegrityStoreResponseH\x00\x12^\n getAzureCommunicationCredentials\x18\x0e \x01(\x0b\x32\x32.metering.GetAzureCommunicationCredentialsResponseH\x00\x42\n\n\x08response\"g\n\x10MeteringResponse\x12\x34\n\x07success\x18\x01 \x01(\x0b\x32!.metering.MeteringSuccessResponseH\x00\x12\x11\n\x07\x66\x61ilure\x18\x02 \x01(\tH\x00\x42\n\n\x08response\"\x98\x01\n\x0b\x44\x63rMetadata\x12+\n\x07purpose\x18\x01 \x01(\x0e\x32\x1a.metering.CreateDcrPurpose\x12\x1c\n\x14showOrganizationLogo\x18\x02 \x01(\x08\x12\x17\n\x0frequirePassword\x18\x03 \x01(\x08\x12%\n\x04kind\x18\x04 \x01(\x0e\x32\x17.metering.CreateDcrKind\"\xb9\x01\n\x10\x43reateDcrRequest\x12\r\n\x05idHex\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1d\n\x15\x64riverAttestationHash\x18\x03 \x01(\t\x12\x19\n\x11participantEmails\x18\x04 \x03(\t\x12\x15\n\x08metadata\x18\x05 \x01(\x0cH\x00\x88\x01\x01\x12*\n\x0b\x65nclaveInfo\x18\x06 \x03(\x0b\x32\x15.metering.EnclaveInfoB\x0b\n\t_metadata\"~\n!ExecuteComputationNodeInteraction\x12\x0e\n\x06nodeId\x18\x01 \x01(\t\x12\x38\n\x0crateLimiting\x18\x02 \x01(\x0b\x32\x1d.data_room.RateLimitingConfigH\x00\x88\x01\x01\x42\x0f\n\r_rateLimiting\"[\n\x1d\x45xecuteComputationInteraction\x12:\n\x05nodes\x18\x01 \x03(\x0b\x32+.metering.ExecuteComputationNodeInteraction\"v\n\x19PublishDatasetInteraction\x12\x0e\n\x06nodeId\x18\x01 \x01(\t\x12\x38\n\x0crateLimiting\x18\x02 \x01(\x0b\x32\x1d.data_room.RateLimitingConfigH\x00\x88\x01\x01\x42\x0f\n\r_rateLimiting\"\xa2\x01\n\x12\x44\x63rInteractionKind\x12\x45\n\x12\x65xecuteComputation\x18\x01 \x01(\x0b\x32\'.metering.ExecuteComputationInteractionH\x00\x12=\n\x0epublishDataset\x18\x02 \x01(\x0b\x32#.metering.PublishDatasetInteractionH\x00\x42\x06\n\x04kind\"\x90\x01\n\x15\x44\x63rInteractionRequest\x12\x14\n\x0c\x64\x61taRoomHash\x18\x01 \x01(\t\x12\x1d\n\x15\x64riverAttestationHash\x18\x02 \x01(\t\x12\x0f\n\x07scopeId\x18\x03 \x01(\t\x12\x31\n\x0binteraction\x18\x04 \x01(\x0b\x32\x1c.metering.DcrInteractionKind\"y\n\x15PublishDatasetRequest\x12\x15\n\rcomputeNodeId\x18\x01 \x01(\t\x12\x14\n\x0cmanifestHash\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61taRoomHash\x18\x03 \x01(\t\x12\x1d\n\x15\x64riverAttestationHash\x18\x04 \x01(\t\"\x99\x02\n\x14\x43reateDatasetRequest\x12\x14\n\x0cmanifestHash\x18\x01 \x01(\t\x12\x15\n\x08manifest\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x07scopeId\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tsizeBytes\x18\x06 \x01(\x04H\x02\x88\x01\x01\x12\x17\n\nstatistics\x18\x07 \x01(\tH\x03\x88\x01\x01\x12\x1c\n\x0f\x64\x61tasetImportId\x18\x08 \x01(\tH\x04\x88\x01\x01\x42\x0b\n\t_manifestB\x0e\n\x0c_descriptionB\x0c\n\n_sizeBytesB\r\n\x0b_statisticsB\x12\n\x10_datasetImportId\"L\n\x1eGetOrCreateDatasetScopeRequest\x12\x19\n\x0cmanifestHash\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_manifestHash\"e\n\x17UnpublishDatasetRequest\x12\x15\n\rcomputeNodeId\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x61taRoomHash\x18\x02 \x01(\t\x12\x1d\n\x15\x64riverAttestationHash\x18\x03 \x01(\t\"E\n\x0eStopDcrRequest\x12\x14\n\x0c\x64\x61taRoomHash\x18\x01 \x01(\t\x12\x1d\n\x15\x64riverAttestationHash\x18\x02 \x01(\t\"\x81\x01\n\x16\x43reateDcrCommitRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x64\x63rIdHex\x18\x02 \x01(\t\x12\x1d\n\x15\x64riverAttestationHash\x18\x03 \x01(\t\x12*\n\x0b\x65nclaveInfo\x18\x06 \x03(\x0b\x32\x15.metering.EnclaveInfo\"\x80\x01\n\x15MergeDcrCommitRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x64\x63rIdHex\x18\x02 \x01(\t\x12\x1d\n\x15\x64riverAttestationHash\x18\x03 \x01(\t\x12*\n\x0b\x65nclaveInfo\x18\x06 \x03(\x0b\x32\x15.metering.EnclaveInfo\"\x13\n\x11\x43reateDcrResponse\"-\n\x1fGetOrCreateDatasetScopeResponse\x12\n\n\x02id\x18\x01 \x01(\t\"\x18\n\x16\x44\x63rInteractionResponse\"\x19\n\x17\x43reateDcrCommitResponse\"\x18\n\x16MergeDcrCommitResponse\"\x11\n\x0fStopDcrResponse\"\x18\n\x16PublishDatasetResponse\"#\n\x15\x43reateDatasetResponse\x12\n\n\x02id\x18\x01 \x01(\t\"\x1a\n\x18UnpublishDatasetResponse\"h\n\x15WorkerMetadataRequest\x12>\n\x0f\x61ttestationSpec\x18\x01 \x01(\x0b\x32%.attestation.AttestationSpecification\x12\x0f\n\x07scopeId\x18\x02 \x01(\t\"5\n\x16WorkerMetadataResponse\x12\x1b\n\x13maxExecutionSeconds\x18\x01 \x01(\x04\"\x91\x01\n SubmitWorkerExecutionTimeRequest\x12\x1c\n\x14\x65xecutionTimeSeconds\x18\x01 \x01(\r\x12>\n\x0f\x61ttestationSpec\x18\x02 \x01(\x0b\x32%.attestation.AttestationSpecification\x12\x0f\n\x07scopeId\x18\x03 \x01(\t\"#\n!SubmitWorkerExecutionTimeResponse\"\x14\n\x12SplickyCredentials\"$\n\x12MicrosoftDspMember\x12\x0e\n\x06member\x18\x01 \x01(\t\"\x8d\x01\n\x0f\x43redentialsKind\x12/\n\x07splicky\x18\x01 \x01(\x0b\x32\x1c.metering.SplickyCredentialsH\x00\x12:\n\x12microsoftDspMember\x18\x02 \x01(\x0b\x32\x1c.metering.MicrosoftDspMemberH\x00\x42\r\n\x0b\x63redentials\"M\n\"GetDataConnectorCredentialsRequest\x12\'\n\x04kind\x18\x01 \x01(\x0b\x32\x19.metering.CredentialsKind\":\n#GetDataConnectorCredentialsResponse\x12\x13\n\x0b\x63redentials\x18\x01 \x01(\t\")\n\'GetAzureCommunicationCredentialsRequest\"d\n(GetAzureCommunicationCredentialsResponse\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x11\n\taccessKey\x18\x02 \x01(\t\x12\x13\n\x0bsenderEmail\x18\x03 \x01(\t*`\n\x10\x43reateDcrPurpose\x12\x0c\n\x08STANDARD\x10\x00\x12\x0e\n\nVALIDATION\x10\x01\x12\x0f\n\x0b\x44\x41TA_IMPORT\x10\x02\x12\x0f\n\x0b\x44\x41TA_EXPORT\x10\x03\x12\x0c\n\x08\x44\x41TA_LAB\x10\x04*n\n\rCreateDcrKind\x12\n\n\x06\x45XPERT\x10\x00\x12\x0f\n\x0b\x44\x41TASCIENCE\x10\x01\x12\t\n\x05MEDIA\x10\x02\x12\x13\n\x0fLOOKALIKE_MEDIA\x10\x03\x12\x12\n\x0eMEDIA_INSIGHTS\x10\x04\x12\x0c\n\x08\x41\x42_MEDIA\x10\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'metering_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CREATEDCRPURPOSE']._serialized_start=5214
  _globals['_CREATEDCRPURPOSE']._serialized_end=5310
  _globals['_CREATEDCRKIND']._serialized_start=5312
  _globals['_CREATEDCRKIND']._serialized_end=5422
  _globals['_ENCLAVEINFO']._serialized_start=87
  _globals['_ENCLAVEINFO']._serialized_end=178
  _globals['_METERINGREQUEST']._serialized_start=181
  _globals['_METERINGREQUEST']._serialized_end=1128
  _globals['_METERINGSUCCESSRESPONSE']._serialized_start=1131
  _globals['_METERINGSUCCESSRESPONSE']._serialized_end=2098
  _globals['_METERINGRESPONSE']._serialized_start=2100
  _globals['_METERINGRESPONSE']._serialized_end=2203
  _globals['_DCRMETADATA']._serialized_start=2206
  _globals['_DCRMETADATA']._serialized_end=2358
  _globals['_CREATEDCRREQUEST']._serialized_start=2361
  _globals['_CREATEDCRREQUEST']._serialized_end=2546
  _globals['_EXECUTECOMPUTATIONNODEINTERACTION']._serialized_start=2548
  _globals['_EXECUTECOMPUTATIONNODEINTERACTION']._serialized_end=2674
  _globals['_EXECUTECOMPUTATIONINTERACTION']._serialized_start=2676
  _globals['_EXECUTECOMPUTATIONINTERACTION']._serialized_end=2767
  _globals['_PUBLISHDATASETINTERACTION']._serialized_start=2769
  _globals['_PUBLISHDATASETINTERACTION']._serialized_end=2887
  _globals['_DCRINTERACTIONKIND']._serialized_start=2890
  _globals['_DCRINTERACTIONKIND']._serialized_end=3052
  _globals['_DCRINTERACTIONREQUEST']._serialized_start=3055
  _globals['_DCRINTERACTIONREQUEST']._serialized_end=3199
  _globals['_PUBLISHDATASETREQUEST']._serialized_start=3201
  _globals['_PUBLISHDATASETREQUEST']._serialized_end=3322
  _globals['_CREATEDATASETREQUEST']._serialized_start=3325
  _globals['_CREATEDATASETREQUEST']._serialized_end=3606
  _globals['_GETORCREATEDATASETSCOPEREQUEST']._serialized_start=3608
  _globals['_GETORCREATEDATASETSCOPEREQUEST']._serialized_end=3684
  _globals['_UNPUBLISHDATASETREQUEST']._serialized_start=3686
  _globals['_UNPUBLISHDATASETREQUEST']._serialized_end=3787
  _globals['_STOPDCRREQUEST']._serialized_start=3789
  _globals['_STOPDCRREQUEST']._serialized_end=3858
  _globals['_CREATEDCRCOMMITREQUEST']._serialized_start=3861
  _globals['_CREATEDCRCOMMITREQUEST']._serialized_end=3990
  _globals['_MERGEDCRCOMMITREQUEST']._serialized_start=3993
  _globals['_MERGEDCRCOMMITREQUEST']._serialized_end=4121
  _globals['_CREATEDCRRESPONSE']._serialized_start=4123
  _globals['_CREATEDCRRESPONSE']._serialized_end=4142
  _globals['_GETORCREATEDATASETSCOPERESPONSE']._serialized_start=4144
  _globals['_GETORCREATEDATASETSCOPERESPONSE']._serialized_end=4189
  _globals['_DCRINTERACTIONRESPONSE']._serialized_start=4191
  _globals['_DCRINTERACTIONRESPONSE']._serialized_end=4215
  _globals['_CREATEDCRCOMMITRESPONSE']._serialized_start=4217
  _globals['_CREATEDCRCOMMITRESPONSE']._serialized_end=4242
  _globals['_MERGEDCRCOMMITRESPONSE']._serialized_start=4244
  _globals['_MERGEDCRCOMMITRESPONSE']._serialized_end=4268
  _globals['_STOPDCRRESPONSE']._serialized_start=4270
  _globals['_STOPDCRRESPONSE']._serialized_end=4287
  _globals['_PUBLISHDATASETRESPONSE']._serialized_start=4289
  _globals['_PUBLISHDATASETRESPONSE']._serialized_end=4313
  _globals['_CREATEDATASETRESPONSE']._serialized_start=4315
  _globals['_CREATEDATASETRESPONSE']._serialized_end=4350
  _globals['_UNPUBLISHDATASETRESPONSE']._serialized_start=4352
  _globals['_UNPUBLISHDATASETRESPONSE']._serialized_end=4378
  _globals['_WORKERMETADATAREQUEST']._serialized_start=4380
  _globals['_WORKERMETADATAREQUEST']._serialized_end=4484
  _globals['_WORKERMETADATARESPONSE']._serialized_start=4486
  _globals['_WORKERMETADATARESPONSE']._serialized_end=4539
  _globals['_SUBMITWORKEREXECUTIONTIMEREQUEST']._serialized_start=4542
  _globals['_SUBMITWORKEREXECUTIONTIMEREQUEST']._serialized_end=4687
  _globals['_SUBMITWORKEREXECUTIONTIMERESPONSE']._serialized_start=4689
  _globals['_SUBMITWORKEREXECUTIONTIMERESPONSE']._serialized_end=4724
  _globals['_SPLICKYCREDENTIALS']._serialized_start=4726
  _globals['_SPLICKYCREDENTIALS']._serialized_end=4746
  _globals['_MICROSOFTDSPMEMBER']._serialized_start=4748
  _globals['_MICROSOFTDSPMEMBER']._serialized_end=4784
  _globals['_CREDENTIALSKIND']._serialized_start=4787
  _globals['_CREDENTIALSKIND']._serialized_end=4928
  _globals['_GETDATACONNECTORCREDENTIALSREQUEST']._serialized_start=4930
  _globals['_GETDATACONNECTORCREDENTIALSREQUEST']._serialized_end=5007
  _globals['_GETDATACONNECTORCREDENTIALSRESPONSE']._serialized_start=5009
  _globals['_GETDATACONNECTORCREDENTIALSRESPONSE']._serialized_end=5067
  _globals['_GETAZURECOMMUNICATIONCREDENTIALSREQUEST']._serialized_start=5069
  _globals['_GETAZURECOMMUNICATIONCREDENTIALSREQUEST']._serialized_end=5110
  _globals['_GETAZURECOMMUNICATIONCREDENTIALSRESPONSE']._serialized_start=5112
  _globals['_GETAZURECOMMUNICATIONCREDENTIALSRESPONSE']._serialized_end=5212
# @@protoc_insertion_point(module_scope)



from __future__ import annotations
import io
import json
from typing import Any, BinaryIO, Dict, TYPE_CHECKING, List, Optional, Union

from ..storage import Key
from .advertiser_computations import (
    GetAudiencesForAdvertiserComputation,
    EstimateAudienceSizeForAdvertiserComputation,
    GetAudienceUserListForAdvertiserComputation,
    GetAudienceUserListForAdvertiserLalComputation,
    RetrievePublishedDatasetsComputation,
    PublishAudiencesJson,
    EstimateAudienceSizeForAdvertiserLalComputation,
    GetLookalikeAudienceStatisticsComputation,
    GetDataAttributesComputation,
)
from .helper import (
    get_parameter_payloads,
    audience_depends_on_lookalike,
    get_dependencies,
)
from .audience_definitions import (
    RuleBasedAudienceDefinition,
    LookalikeAudienceDefinition,
    AdvertiserAudienceDefinition,
    AudienceDefinitions
)
from .audience_statistics_definition import LalAudienceStatistics
from decentriq_dcr_compiler.schemas import Audience2, Audience3
from decentriq_dcr_compiler.schemas import AbMediaRequest
from .request import Request
from .version import AUDIENCES_JSON_SUPPORTED_VERSION
from .audience_definitions import AudienceStatus

if TYPE_CHECKING:
    from .ab_media import AbMediaDcr


class Attribute:
    def __init__(self, name: str, values: List[str]) -> None:
        self.name = name
        self.values = values

    def as_dict(self) -> Dict[str, Any]:
        return {"name": self.name, "values": self.values}


class AdvertiserApi:
    """
    Provides the API for interacting with an Audience Builder DCR as an advertiser.
    """

    def __init__(self, dcr: AbMediaDcr) -> None:
        self.dcr_id = dcr.id
        self.session = dcr.session
        self.client = dcr.client
        self.features = dcr.features

    def upload_and_publish_audiences_dataset(
        self,
        data: BinaryIO,
        key: Key,
        file_name: str,
    ) -> None:
        """
        Upload the data to the Decentriq Platform and publish
        the data to the Audience Builder DCR.

        **Parameters**:
        - `data`: The data to upload and provision.
        - `key`: Key used to encrypt the file.
        - `file_name`: Name of the file.
        """
        audiences_dataset_id = self.client.upload_dataset(data, key, file_name)
        self.provision_audiences_dataset(audiences_dataset_id, key)

    def provision_audiences_dataset(self, dataset_id: str, key: Key) -> None:
        """
        Provision the audiences dataset to the Audience Builder DCR.

        **Parameters**:
        - `dataset_id`: ID of the uploaded dataset to provision to the DCR.
        - `key`: Key used to encrypt the dataset.
        """
        request_key = "publishAudiencesDataset"
        request = AbMediaRequest.model_validate(
            {
                request_key: {
                    "dataRoomIdHex": self.dcr_id,
                    "datasetHashHex": dataset_id,
                    "encryptionKeyHex": key.material.hex(),
                    "scopeIdHex": self.client._ensure_dcr_data_scope(self.dcr_id),
                },
            }
        )
        response = Request.send(request, self.session)
        if request_key not in response.model_dump_json():
            raise Exception(
                f"Failed to provision the audiences dataset to the Audience Builder DCR"
            )

    def deprovision_audiences_dataset(self) -> None:
        """
        Deprovision the audiences dataset from the Audience Builder DCR.
        """
        request_key = "unpublishAudiencesDataset"
        request = AbMediaRequest.model_validate(
            {
                request_key: {
                    "dataRoomIdHex": self.dcr_id,
                },
            }
        )
        response = Request.send(request, self.session)
        if request_key not in response.model_dump_json():
            raise Exception(
                f"Failed to deprovision the audiences dataset from the Audience Builder DCR"
            )

    def get_audiences(
        self,
    ) -> AudienceDefinitions:
        """
        Retrieve all advertiser audiences.
        """
        if (
            not self.features.has_enable_lookalike_audiences()
            and not self.features.has_enable_remarketing()
            and not self.features.has_enable_rule_based_audiences()
        ):
            raise Exception(
                "Unable to retrieve audiences. Lookalike, remarketing or rule-based features must be enabled."
            )

        audiences_dict = self._request_audiences()
        audiences = []
        for a in audiences_dict["audiences"]:
            if a["kind"] == "rulebased":
                audiences.append(
                    RuleBasedAudienceDefinition.from_dict(
                        a, audiences_dict["audiences"]
                    )
                )
            elif a["kind"] == "lookalike":
                audiences.append(
                    LookalikeAudienceDefinition.from_dict(
                        a, audiences_dict["audiences"]
                    )
                )
            elif a["kind"] == "advertiser":
                audiences.append(
                    AdvertiserAudienceDefinition.from_dict(
                        a, audiences_dict["audiences"]
                    )
                )
            else:
                raise Exception(f'Audience kind "{a["kind"]}" unknown')

        return audiences

    def _request_audiences(self) -> Dict[str, Any]:
        """
        Retrieve the audiences data structure as provided by the backend.
        """
        computation = GetAudiencesForAdvertiserComputation(
            dcr_id=self.dcr_id, client=self.client, session=self.session
        )
        return computation.run_and_get_results()

    def estimate_audience_size(self, audience_name: str) -> int:
        """
        Estimate the audience size for the advertiser.

        **Parameters**:
        - `audience_name`: Name of the audience for which the estimated audience size should be retrieved.
        """
        audiences_json = self._request_audiences()
        payloads = get_parameter_payloads(
            audience_name=audience_name, audiences_json=audiences_json
        )

        if audience_depends_on_lookalike(
            audience_name=audience_name, audiences_json=audiences_json
        ):
            computation = EstimateAudienceSizeForAdvertiserLalComputation(
                dcr_id=self.dcr_id,
                client=self.client,
                session=self.session,
                generate_audience=payloads.generate,
                lal_audience=payloads.lal,
            )
            result = computation.run_and_get_results()
            return result["audience_size"]
        else:
            computation = EstimateAudienceSizeForAdvertiserComputation(
                dcr_id=self.dcr_id,
                client=self.client,
                session=self.session,
                generate_audience=payloads.generate,
            )
            result = computation.run_and_get_results()
            return result["audience_size"]

    def get_audience_user_list(self, audience_name: str) -> List[str]:
        """
        Get the list of user IDs for the advertiser.

        **Parameters**:
        - `audience_name`: Name of the audience for which the audience user list should be retrieved.
        """
        if not self.features.has_enable_advertiser_audience_download():
            raise Exception(
                "This Audience Builder DCR does not support downloading audiences for advertisers"
            )

        audiences_json = self._request_audiences()
        payloads = get_parameter_payloads(
            audience_name=audience_name, audiences_json=audiences_json
        )

        if audience_depends_on_lookalike(
            audience_name=audience_name, audiences_json=audiences_json
        ):
            computation = GetAudienceUserListForAdvertiserLalComputation(
                dcr_id=self.dcr_id,
                client=self.client,
                session=self.session,
                generate_audience=payloads.generate,
                lal_audience=payloads.lal,
            )
            return computation.run_and_get_results()
        else:
            computation = GetAudienceUserListForAdvertiserComputation(
                dcr_id=self.dcr_id,
                client=self.client,
                session=self.session,
                generate_audience=payloads.generate,
            )
            return computation.run_and_get_results()

    def make_audiences_available_to_publisher(self, audience_names: List[str]):
        """
        Make the audiences with the given names available to the Publisher.
        The Publisher will be able to download the user ids belonging to these audiences.

        **Parameters**:
        - `audience_names`: Names of the audiences to make available to the publisher.
        """
        audiences_json = self._request_audiences()
        audiences = audiences_json.pop("audiences")
        audiences_dict = {a["mutable"]["name"]: a for a in audiences}

        for audience_name in audience_names:
            if audience_name not in audiences_dict:
                raise Exception(
                    f'Audience with name "{audience_name}" not in the list of available audiences'
                )

            # Set the status of the audience to "published".
            audience_to_activate = audiences_dict[audience_name]
            audience_to_activate["mutable"]["status"] = "published"
            audiences_dict[audience_name] = audience_to_activate

        # Update the audiences in the `audiences.json`.
        audiences_json["audiences"] = [a for a in audiences_dict.values()]
        self._upload_and_publish_audiences_json(audiences_json=audiences_json)

    def add_audiences(
        self,
        audiences: list[
            LookalikeAudienceDefinition
            | RuleBasedAudienceDefinition
        ],
    ):
        """
        Add the given audiences to the current DCR.
        The audiences will only be visible to the publisher after they have been published.

        **Parameters**:
        - `audiences`: The audience definitions to add.
        """

        # Get the existing audiences.
        audiences_json = self._request_audiences()
        existing_audiences = audiences_json.pop("audiences")
        audiences_dict = {}
        for a in existing_audiences:
            audience_name = a["mutable"]["name"]
            if audience_name in audiences_dict:
                raise Exception(f'Multiple audiences with name "{audience_name}"')
            audiences_dict[audience_name] = a
        existing_audiences_by_id = {a["id"]: a for a in audiences_dict.values()}

        # Add the new audiences.
        new_audiences_by_id = {a.id: a for a in audiences}
        all_audiences = existing_audiences + [new_audience.as_dict() for new_audience in audiences]
        for audience in audiences:
            if isinstance(audience, LookalikeAudienceDefinition):
                # Additional checks for lookalike audiences.
                if not self.features.has_enable_lookalike_audiences():
                    raise Exception(
                        "This Audience Builder DCR does not support Lookalike audiences"
                    )
                if audience.reach < 0 or audience.reach > 30:
                    raise Exception(
                        "Reach value must be an integer in the range 0 - 30"
                    )

            if audience.name in audiences_dict:
                raise Exception(
                    f'Audience with name "{audience.name}" already exists in audience list'
                )

            # Check if we need to mark any of the existing dependencies as PUBLISHED_AS_INTERMEDIATE
            # in order for them to be retrievable by the publisher.
            if audience.status == AudienceStatus.PUBLISHED:
                dependency_ids = get_dependencies(audience.id, all_audiences)
                for audience_id in dependency_ids:
                    if audience_id in existing_audiences_by_id:
                        dependency = existing_audiences_by_id[audience_id]
                        if dependency["mutable"]["status"] == AudienceStatus.READY.value:
                            dependency["mutable"]["status"] = AudienceStatus.PUBLISHED_AS_INTERMEDIATE.value
                    elif audience_id in new_audiences_by_id:
                        # Check whether the dependency is added as part of the same call.
                        # If yes, then it must have a published state.
                        dependency = new_audiences_by_id[audience_id]
                        if dependency.status == AudienceStatus.READY:
                            dependency.status = AudienceStatus.PUBLISHED_AS_INTERMEDIATE
                    else:
                        raise Exception(
                            f"Unable to find audience dependency '{audience_id}' in neither the existing audiences nor the audiences to be added"
                        )

        # Loop again over the audiences and dump them in JSON format.
        # The second loop is required since some of the audiences (that are dependencies
        # of other audiences to be added) got their status changed.
        for audience in audiences:
            parsed_audience = audience._as_ddc_audience()  # parse into the DDC representation
            audiences_dict[audience.name] = parsed_audience.model_dump(mode="json")

        # Update the audiences.json.
        audiences_json["audiences"] = [a for a in audiences_dict.values()]
        self._upload_and_publish_audiences_json(audiences_json=audiences_json)

    def get_audience_attributes(self) -> List[Attribute]:
        """
        Retrieve all audience attributes.
        These attributes can be used to build new rule-based audiences.
        """
        computation = GetDataAttributesComputation(
            dcr_id=self.dcr_id,
            client=self.client,
            session=self.session,
        )
        results = computation.run_and_get_results()
        attributes = [
            Attribute(k, v["values"]) for k, v in results["attributes"].items()
        ]
        return attributes

    def get_lookalike_audience_statistics(
        self, audience_name: str
    ) -> LalAudienceStatistics:
        """
        Retrieve lookalike statistics for an audience with the given name.

        **Parameters**:
        - `audience_name`: Name of the audience whose lookalike statistics should be retrieved.
        """
        audiences_json = self._request_audiences()
        if audience_depends_on_lookalike(
            audience_name=audience_name, audiences_json=audiences_json
        ):
            raise Exception("Requested audience cannot be a Lookalike audience")

        payloads = get_parameter_payloads(
            audience_name=audience_name, audiences_json=audiences_json
        )
        computation = GetLookalikeAudienceStatisticsComputation(
            dcr_id=self.dcr_id,
            client=self.client,
            session=self.session,
            generate_audience=payloads.generate,
        )
        results = computation.run_and_get_results()
        return LalAudienceStatistics.from_dict(results)

    def _update_manifest_hashes_in_audiences_json(self, audiences_json: Dict[str, Any]):
        # Set the dataset hashes to the latest versions.
        datasets = self._retrieve_published_datasets()
        if "matchingDatasetHashHex" not in datasets:
            raise Exception("Matching dataset must be provisioned to the DCR")
        audiences_json["matching_manifest_hash"] = datasets["matchingDatasetHashHex"]
        if "segmentsDatasetHashHex" in datasets:
            audiences_json["segments_manifest_hash"] = datasets[
                "segmentsDatasetHashHex"
            ]
        if "embeddingsDatasetHashHex" in datasets:
            audiences_json["embeddings_manifest_hash"] = datasets[
                "embeddingsDatasetHashHex"
            ]
        if "demographicsDatasetHashHex" in datasets:
            audiences_json["demographics_manifest_hash"] = datasets[
                "demographicsDatasetHashHex"
            ]
        if "audiencesDatasetHashHex" in datasets:
            audiences_json["advertiser_manifest_hash"] = datasets[
                "audiencesDatasetHashHex"
            ]

    def _upload_and_publish_audiences_json(self, audiences_json: Dict[str, Any]):
        audiences_json["version"] = AUDIENCES_JSON_SUPPORTED_VERSION

        # Update the manifest hashes whenever the `audiences.json` is published.
        self._update_manifest_hashes_in_audiences_json(audiences_json=audiences_json)

        key = Key()
        manifest_hash = self.client.upload_dataset(
            io.BytesIO(json.dumps(audiences_json).encode()),
            key,
            "audiences.json",
        )
        publish_audiences_json = PublishAudiencesJson(
            dcr_id=self.dcr_id,
            manifest_hash=manifest_hash,
            encryption_key_hex=key.material.hex(),
            client=self.client,
            session=self.session,
        )
        publish_audiences_json.run()

    def _retrieve_published_datasets(self) -> Dict[str, Any]:
        """
        Get all datasets that have been published to the DCR.
        """
        retrieve_published_datasets_computation = RetrievePublishedDatasetsComputation(
            dcr_id=self.dcr_id,
            client=self.client,
            session=self.session,
        )
        return retrieve_published_datasets_computation.run_and_get_results()



from __future__ import annotations

import json

from typing import Any, Dict, TYPE_CHECKING, List, Union
from decentriq_dcr_compiler import compiler, ab_media as ab_media_compiler
from decentriq_dcr_compiler.schemas import AbMediaRequest
from .publisher_computations import (
    GetAudiencesForPublisherComputation,
    EstimateAudienceSizeForPublisherComputation,
    GetAudienceUserListForPublisherComputation,
    EstimateAudienceSizeForPublisherLalComputation,
    GetAudienceUserListForPublisherLalComputation,
    ComputeInsightsComputation,
)
from .helper import (
    get_parameter_payloads,
    audience_depends_on_lookalike,
)
from .audience_definitions import (
    RuleBasedAudienceDefinition,
    LookalikeAudienceDefinition,
    AdvertiserAudienceDefinition,
)
from .request import Request
from ..storage import Key

if TYPE_CHECKING:
    from ..client import Client


class PublisherApi:
    """
    Provides the API for interacting with an Audience Builder DCR as a publisher.
    """

    def __init__(self, dcr: AbMediaDcr) -> None:
        self.dcr_id = dcr.id
        self.session = dcr.session
        self.client = dcr.client
        self.high_level_dcr = dcr.high_level
        self.features = dcr.features

    def get_audiences(
        self,
    ) -> List[
        Union[
            RuleBasedAudienceDefinition
            | LookalikeAudienceDefinition
            | AdvertiserAudienceDefinition
        ]
    ]:
        """
        Get the audiences for the publisher.
        """
        if (
            not self.features.has_enable_lookalike_audiences()
            and not self.features.has_enable_remarketing()
            and not self.features.has_enable_rule_based_audiences()
        ):
            raise Exception(
                "Unable to retrieve audiences. Lookalike, remarketing or rule-based features must be enabled."
            )

        audiences_dict = self._request_audiences()
        audiences = []
        for a in audiences_dict["audiences"]:
            if a["kind"] == "rulebased":
                audiences.append(
                    RuleBasedAudienceDefinition.from_dict(
                        a, audiences_dict["audiences"]
                    )
                )
            elif a["kind"] == "lookalike":
                audiences.append(
                    LookalikeAudienceDefinition.from_dict(
                        a, audiences_dict["audiences"]
                    )
                )
            elif a["kind"] == "advertiser":
                audiences.append(
                    AdvertiserAudienceDefinition.from_dict(
                        a, audiences_dict["audiences"]
                    )
                )
            else:
                raise Exception(f'Audience kind "{a["kind"]}" unknown')

        return audiences

    def _request_audiences(self) -> Dict[str, Any]:
        """
        Retrieve the audiences data structure as provided by the backend.
        """
        computation = GetAudiencesForPublisherComputation(
            dcr_id=self.dcr_id, client=self.client, session=self.session
        )
        return computation.run_and_get_results()

    def estimate_audience_size(self, audience_name: str) -> int:
        """
        Estimate the audience size for the publisher.
        """
        audiences_json = self._request_audiences()
        payloads = get_parameter_payloads(
            audience_name=audience_name, audiences_json=audiences_json
        )

        if audience_depends_on_lookalike(
            audience_name=audience_name, audiences_json=audiences_json
        ):
            computation = EstimateAudienceSizeForPublisherLalComputation(
                dcr_id=self.dcr_id,
                client=self.client,
                session=self.session,
                generate_audience=payloads.generate,
                lal_audience=payloads.lal,
            )
            result = computation.run_and_get_results()
            return result["audience_size"]
        else:
            computation = EstimateAudienceSizeForPublisherComputation(
                dcr_id=self.dcr_id,
                client=self.client,
                session=self.session,
                generate_audience=payloads.generate,
            )
            result = computation.run_and_get_results()
            return result["audience_size"]

    def get_audience_user_list(self, audience_name: str) -> List[str]:
        """
        Get the audience user list for the publisher.
        """
        if (
            not self.features.has_enable_lookalike_audiences()
            and not self.features.has_enable_remarketing()
            and not self.features.has_enable_rule_based_audiences()
        ):
            raise Exception(
                "Unable to retrieve audience user list. Lookalike, remarketing or rule-based features must be enabled."
            )

        audiences_json = self._request_audiences()
        payloads = get_parameter_payloads(
            audience_name=audience_name, audiences_json=audiences_json
        )

        if audience_depends_on_lookalike(
            audience_name=audience_name, audiences_json=audiences_json
        ):
            computation = GetAudienceUserListForPublisherLalComputation(
                dcr_id=self.dcr_id,
                client=self.client,
                session=self.session,
                generate_audience=payloads.generate,
                lal_audience=payloads.lal,
            )
            return computation.run_and_get_results()
        else:
            computation = GetAudienceUserListForPublisherComputation(
                dcr_id=self.dcr_id,
                client=self.client,
                session=self.session,
                generate_audience=payloads.generate,
            )
            return computation.run_and_get_results()

    def get_insights(self) -> Dict[str, Any]:
        """
        Get the insights.
        """
        if not self.features.has_enable_insights():
            raise Exception("This Audience Builder DCR does not support insights.")

        overlap_insights_computation = ComputeInsightsComputation(
            dcr_id=self.dcr_id, client=self.client, session=self.session
        )
        return overlap_insights_computation.run_and_get_results()

    def provision_from_data_lab(self, data_lab_id: str):
        """
        Provision the DataLab with the given ID to the Audience Builder DCR.

        **Parameters**:
        - `data_lab_id`: ID of the DataLab to provision to the Audience Builder DCR.
        """
        # First deprovision any existing datalabs before provisioning a new one.
        # This ensures that we don't get into issues with optional datasets not
        # being updated.
        self.deprovision_data_lab()

        # Check DataLab is validated
        data_lab = self.client.get_data_lab(data_lab_id)
        if not data_lab["isValidated"]:
            raise Exception("Cannot provision DataLab, not validated.")

        # Check compatibility
        hl_data_lab = data_lab["highLevelRepresentationAsString"]
        compatible = (
            ab_media_compiler.is_data_lab_compatible_with_ab_media_dcr_serialized(
                hl_data_lab, json.dumps(self.high_level_dcr)
            )
        )
        if not compatible:
            raise Exception("DataLab is incompatible with Audience Builder DCR")

        # Provision datasets
        data_lab_datasets = self._get_data_lab_datasets_dict(data_lab)

        # Provision all existing Data Lab datasets to the DCR.
        for dataset_type, dataset in data_lab_datasets.items():
            if not dataset:
                # Dataset was not provisioned to the Data Lab.
                continue
            manifest_hash = dataset["manifestHash"]
            encryption_key = self.client.get_dataset_key(manifest_hash)
            if dataset_type == "MATCHING_DATA":
                request_key = "publishMatchingDataset"
            elif dataset_type == "SEGMENTS_DATA":
                request_key = "publishSegmentsDataset"
            elif dataset_type == "DEMOGRAPHICS_DATA":
                request_key = "publishDemographicsDataset"
            elif dataset_type == "EMBEDDINGS_DATA":
                request_key = "publishEmbeddingsDataset"
            else:
                raise Exception(
                    f"Failed to provision Data Lab. Dataset type '{dataset_type}' unknown."
                )
            self._send_publish_dataset_request(
                request_key, manifest_hash, encryption_key
            )

        # Update DB.
        provisioned_data_lab_id = self.client._provision_data_lab_to_ab_dcr(
            self.dcr_id, data_lab_id
        )["id"]
        if provisioned_data_lab_id != data_lab_id:
            raise Exception(
                f"Incorrectly provisioned DataLab {provisioned_data_lab_id}"
            )

    def _get_data_lab_datasets_dict(self, data_lab: compiler.DataLab):
        datasets_dict = {}
        for dataset in data_lab["datasets"]:
            datasets_dict[dataset["name"]] = dataset["dataset"]
        return datasets_dict

    def _send_publish_dataset_request(
        self, request_key: str, manifest_hash: str, encryption_key: Key
    ):
        request = AbMediaRequest.model_validate(
            {
                request_key: {
                    "dataRoomIdHex": self.dcr_id,
                    "datasetHashHex": manifest_hash,
                    "encryptionKeyHex": encryption_key.material.hex(),
                    "scopeIdHex": self.client._ensure_dcr_data_scope(self.dcr_id),
                },
            }
        )
        response = Request.send(request, self.session)
        if request_key not in response.model_dump_json():
            raise Exception(f'Failed to publish "{request_key}"')

    # This function should not throw on repeated calls. This allows it to be
    # called when provisioning also (where there may not yet be any data provisioned).
    def deprovision_data_lab(self):
        """
        Deprovision a DataLab from the Audience Builder DCR.
        """
        # Get a list of published datasets
        request = AbMediaRequest.model_validate(
            {
                "retrievePublishedDatasets": {
                    "dataRoomIdHex": self.dcr_id,
                },
            }
        )
        response = Request.send(request, self.session)
        datasets = response.model_dump()["retrievePublishedDatasets"]
        if datasets["matchingDatasetHashHex"]:
            request_key = "unpublishMatchingDataset"
        elif datasets["segmentsDatasetHashHex"]:
            request_key = "unpublishSegmentsDataset"
        elif datasets["demographicsDatasetHashHex"]:
            request_key = "unpublishDemographicsDataset"
        elif datasets["embeddingsDatasetHashHex"]:
            request_key = "unpublishEmbeddingsDataset"
        else:
            request_key = None

        if request_key:
            self._send_unpublish_dataset_request(request_key)
            # Update DB.
            data_lab = self.client._deprovision_data_lab_from_ab_dcr(self.dcr_id)
            if data_lab:
                raise Exception("DataLab should have been deprovisioned")

    def _send_unpublish_dataset_request(self, request_key: str):
        request = AbMediaRequest.model_validate(
            {
                request_key: {
                    "dataRoomIdHex": self.dcr_id,
                },
            }
        )
        response = Request.send(request, self.session)
        if request_key not in response.model_dump_json():
            raise Exception(f"Failed to unpublish {request_key}")
